# BUILD-REPORT-v1.10.0.md — agentkit-cli dispatch lanes

Status: SHIPPED
Release commit: `a87c03d28fbe3f235d0b5909614c544e5439dcdd`
Tag: `v1.10.0`
Branch: `feat/v1.10.0-dispatch-lanes`
PyPI: https://pypi.org/project/agentkit-cli/1.10.0/

See `BUILD-REPORT.md` for the full shipped report for `v1.10.0`.
